==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/Tie/ExternalAllLockFile.pm <==
#
# WiKicker
#
#  ExternalAllLockFile.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: ExternalAllLockFile.pm,v 1.1.1.1 2003/05/18 14:03:53 naney Exp $
#
#

package WiKicker::Tie::ExternalAllLockFile;

use 5.005;
use strict;
use WiKicker::Tie::File;

use vars qw(@ISA);
@ISA = qw(WiKicker::Tie::File);

sub shared_lock_all_by_external {
  shift->{lock_all_by_external} = 1;
}

sub exclusive_lock_all_by_external {
  shift->{lock_all_by_external} = 2;
}

sub unlock_all_by_external {
  shift->{lock_all_by_external} = 0;
}

sub shared_lock_key {
  die "No shared lock" unless shift->{lock_all_by_external} >= 1;
}

sub exclusive_lock_key {
  die "No exclusive lock" unless shift->{lock_all_by_external} >= 2;
}

sub unlock_key {
  # ignore
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/Tie/ExternalAllLockFile.pm <==
#
# WiKicker
#
#  ExternalAllLockFile.pm
#
#
# Copyright (C) 2003,2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: ExternalAllLockFile.pm,v 1.3 2005/05/06 13:06:47 naney Exp $
#
#

package WiKicker::Tie::ExternalAllLockFile;

use 5.005;
use strict;
use Carp;
use WiKicker::Tie::File;

use vars qw(@ISA);
@ISA = qw(WiKicker::Tie::File);

sub shared_lock_all_by_external {
  shift->{lock_all_by_external} = 1;
}

sub exclusive_lock_all_by_external {
  shift->{lock_all_by_external} = 2;
}

sub unlock_all_by_external {
  shift->{lock_all_by_external} = 0;
}

sub shared_lock_key {
  croak q|Can't shared lock (not locked by external)|
    unless shift->{lock_all_by_external} >= 1;
}

sub exclusive_lock_key {
  die 'No exclusive lock' unless shift->{lock_all_by_external} >= 2;
}

sub unlock_key {
  # ignore
}

1;
